Update of /cvsroot/fink/dists/10.2/stable/main/finkinfo/base
In directory sc8-pr-cvs1:/tmp/cvs-serv23305/stable/main/finkinfo/base

Added Files:
        debconf-1.0.32-1.info debconf-1.0.32-1.patch 
Log Message:
moving stuff to stable...

--- NEW FILE: debconf-1.0.32-1.info ---
Package: debconf
Version: 1.0.32
Revision: 1
BuildDepends: findutils
Depends: dialog
Type: perl
Source: mirror:debian:/pool/main/d/debconf/%n_%v.tar.gz
Source-MD5: d76845952ee4ea4789d555a587fb1cd7
#SourceRename: %n-%v.tar.gz
SourceDirectory: %n
PatchScript: sed 's|@FINKPREFIX@|%p|' < %a/%f.patch | patch -p1
UpdatePOD: true
CompileScript: <<
#!/bin/sh
cd doc
make all
cd ..
make -C po
<<
InstallScript: <<
  mkdir -p %i/etc/apt/apt.conf.d
  install -m 0644 debian/apt.conf %i/etc/apt/apt.conf.d/70debconf
  make install prefix=%i
  make install-utils prefix=%i
  make install-rest prefix=%i
  mkdir -p %i/share/doc/%n  
  rm -rf samples/CVS
  mv samples %i/share/doc/%n/

  mkdir -p %i/share/man/man3
  mv %b/doc/man/*.3 %i/share/man/man3

  mkdir -p %i/share/man/man5
  mv %b/doc/man/*.5 %i/share/man/man5

  mkdir -p %i/share/man/man8
  mv %b/doc/man/*.8 %i/share/man/man8

  mkdir -p %i/share/podfiles
  mv %b/doc/man/*.pod %i/share/podfiles

  mkdir -p %d/DEBIAN
  cp debian/config debian/templates %d/DEBIAN
<<
# Fix up broken db's before debconf starts up.
PostInstScript: <<
if [ -z "$DEBIAN_HAS_FRONTEND" -a "$1" = configure ] && \
   dpkg --compare-versions "$2" lt 1.0.25; then
        %p/share/debconf/fix_db.pl
fi

. %p/share/debconf/confmodule
<<

DocFiles: doc/COPYRIGHT doc/EXAMPLES doc/README.LDAP doc/CREDITS doc/Makefile 
doc/README.translators doc/CREDITS doc/Makefile doc/README.translators doc/README 
doc/TODO doc/debconf.schema doc/passthrough.txt doc/graph.pl doc/tutorial.xml 
doc/html.dsl doc/namespace.txt
Description: Package configuration management system
DescDetail: <<
Debconf is a configuration management system for debian/fink packages. Packages use 
Debconf to ask questions when they are installed.
<<
License: GPL
Maintainer: Chris Zubrzycki <[EMAIL PROTECTED]>
Homepage: http://packages.debian.org/stable/admin/debconf.html

--- NEW FILE: debconf-1.0.32-1.patch ---
diff -ruN debconf/transition_db.pl debconf.new/transition_db.pl
--- debconf/transition_db.pl    2001-03-18 19:12:35.000000000 -0500
+++ debconf.new/transition_db.pl        2003-03-14 13:39:25.000000000 -0500
@@ -6,7 +6,7 @@
 use Debconf::Question;
 use Debconf::Template;
 
-my $dir = shift || '/var/lib/debconf';
+my $dir = shift || '@FINKPREFIX@/var/lib/debconf';
 
 Debconf::Db->load;
 




-------------------------------------------------------
This SF.NET email is sponsored by: eBay
Great deals on office technology -- on eBay now! Click here:
http://adfarm.mediaplex.com/ad/ck/711-11697-6916-5
_______________________________________________
Fink-commits mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/fink-commits

Reply via email to
diff -ruN debconf/Debconf/Client/ConfModule.pm debconf.new/Debconf/Client/ConfModule.pm
--- debconf/Debconf/Client/ConfModule.pm        2001-11-17 13:36:37.000000000 -0500
+++ debconf.new/Debconf/Client/ConfModule.pm    2003-03-14 13:39:23.000000000 -0500
@@ -68,14 +68,14 @@
 =cut
 
 sub import {
-       exec "/usr/share/debconf/frontend", $0, @ARGV
+       exec "@FINKPREFIX@/share/debconf/frontend", $0, @ARGV
                unless $ENV{DEBIAN_HAS_FRONTEND};
 
        # Make the Exporter still work.
        Debconf::Client::ConfModule->export_to_level(1, @_);
 
        # A truely gross hack. This only is needed if
        # /usr/share/debconf/confmodule is loaded, and then this
        # perl module is used. In that case, this module needs to write
        # to fd #3, rather than stdout. See changelog 0.3.74.
[...1075 lines suppressed...]
 #!/bin/sh -e
 
 # Source debconf library.
-. /usr/share/debconf/confmodule
+. @FINKPREFIX@/share/debconf/confmodule
 db_version 2.0
 
 # This conf script is capable of backing up
@@ -68,14 +68,14 @@
 
        # A truely gross hack. This only is needed if
-       # /usr/share/debconf/confmodule is loaded, and then this
+       # @FINKPREFIX@/share/debconf/confmodule is loaded, and then this
        # perl module is used. In that case, this module needs to write
        # to fd #3, rather than stdout. See changelog 0.3.74.